#!/usr/bin/env python3

import click
import logging
from pathlib import Path
from geo_processor import GeoProcessor
from srtm_downloader import SRTMDownloader

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)

@click.command()
@click.option('--boundary-file', required=True, help='Path to boundary file (KMZ/GeoJSON)')
@click.option('--output-dir', default='./data/output', help='Output directory for SRTM files')
@click.option('--temp-dir', default='./data/temp', help='Temporary directory for processing')
def main(boundary_file, output_dir, temp_dir):
    """Download SRTM data for given geographic boundary."""
    try:
        logger.info(f"Processing boundary file: {boundary_file}")
        
        # Create directories
        Path(output_dir).mkdir(parents=True, exist_ok=True)
        Path(temp_dir).mkdir(parents=True, exist_ok=True)
        
        # Process geographic boundary
        geo_processor = GeoProcessor(boundary_file)
        bounds = geo_processor.get_bounds()
        
        # Download SRTM data
        downloader = SRTMDownloader(output_dir, temp_dir)
        downloader.download_for_bounds(bounds)
        
        logger.info("Processing completed successfully")
        
    except Exception as e:
        logger.error(f"Error during processing: {e}")
        raise

if __name__ == '__main__':
    main()